==> quantlib_0.3.9.orig.tar.gz: QuantLib-0.3.9/ql/Calendars/all.hpp <==
/* -*- mode: c++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */

/*
 Copyright (C) 2003 StatPro Italia srl

 This file is part of QuantLib, a free-software/open-source library
 for financial quantitative analysts and developers - http://quantlib.org/

 QuantLib is free software: you can redistribute it and/or modify it
 under the terms of the QuantLib license.  You should have received a
 copy of the license along with this program; if not, please email
 <quantlib-dev@lists.sf.net>. The license is also available online at
 <http://quantlib.org/reference/license.html>.

 This program is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 FOR A PARTICULAR PURPOSE.  See the license for more details.
*/

#ifndef quantlib_calendars_all_hpp
#define quantlib_calendars_all_hpp

#include <ql/qldefines.hpp>

#include <ql/Calendars/beijing.hpp>
#include <ql/Calendars/bratislava.hpp>
#include <ql/Calendars/budapest.hpp>
#include <ql/Calendars/copenhagen.hpp>
#include <ql/Calendars/germany.hpp>
#include <ql/Calendars/helsinki.hpp>
#include <ql/Calendars/hongkong.hpp>
#include <ql/Calendars/italy.hpp>
#include <ql/Calendars/johannesburg.hpp>
#include <ql/Calendars/jointcalendar.hpp>
#include <ql/Calendars/nullcalendar.hpp>
#include <ql/Calendars/oslo.hpp>
#include <ql/Calendars/prague.hpp>
#include <ql/Calendars/riyadh.hpp>
#include <ql/Calendars/seoul.hpp>
#include <ql/Calendars/singapore.hpp>
#include <ql/Calendars/stockholm.hpp>
#include <ql/Calendars/sydney.hpp>
#include <ql/Calendars/taiwan.hpp>
#include <ql/Calendars/target.hpp>
#include <ql/Calendars/tokyo.hpp>
#include <ql/Calendars/toronto.hpp>
#include <ql/Calendars/unitedkingdom.hpp>
#include <ql/Calendars/unitedstates.hpp>
#include <ql/Calendars/warsaw.hpp>
#include <ql/Calendars/wellington.hpp>
#include <ql/Calendars/zurich.hpp>


#endif

==> quantlib_0.3.11.orig.tar.gz: QuantLib-0.3.11/ql/Calendars/all.hpp <==
/* -*- mode: c++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */

/*
 Copyright (C) 2003 StatPro Italia srl

 This file is part of QuantLib, a free-software/open-source library
 for financial quantitative analysts and developers - http://quantlib.org/

 QuantLib is free software: you can redistribute it and/or modify it
 under the terms of the QuantLib license.  You should have received a
 copy of the license along with this program; if not, please email
 <quantlib-dev@lists.sf.net>. The license is also available online at
 <http://quantlib.org/reference/license.html>.

 This program is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 FOR A PARTICULAR PURPOSE.  See the license for more details.
*/

#ifndef quantlib_calendars_all_hpp
#define quantlib_calendars_all_hpp

#include <ql/qldefines.hpp>

#include <ql/Calendars/beijing.hpp>
#include <ql/Calendars/bombay.hpp>
#include <ql/Calendars/bratislava.hpp>
#include <ql/Calendars/budapest.hpp>
#include <ql/Calendars/copenhagen.hpp>
#include <ql/Calendars/germany.hpp>
#include <ql/Calendars/helsinki.hpp>
#include <ql/Calendars/hongkong.hpp>
#include <ql/Calendars/italy.hpp>
#include <ql/Calendars/istanbul.hpp>
#include <ql/Calendars/johannesburg.hpp>
#include <ql/Calendars/jointcalendar.hpp>
#include <ql/Calendars/nullcalendar.hpp>
#include <ql/Calendars/oslo.hpp>
#include <ql/Calendars/prague.hpp>
#include <ql/Calendars/riyadh.hpp>
#include <ql/Calendars/seoul.hpp>
#include <ql/Calendars/singapore.hpp>
#include <ql/Calendars/stockholm.hpp>
#include <ql/Calendars/sydney.hpp>
#include <ql/Calendars/taipei.hpp>
#include <ql/Calendars/taiwan.hpp>
#include <ql/Calendars/target.hpp>
#include <ql/Calendars/tokyo.hpp>
#include <ql/Calendars/toronto.hpp>
#include <ql/Calendars/unitedkingdom.hpp>
#include <ql/Calendars/unitedstates.hpp>
#include <ql/Calendars/warsaw.hpp>
#include <ql/Calendars/wellington.hpp>
#include <ql/Calendars/zurich.hpp>


#endif
